﻿using PayCRM.Models;
using System.Linq;
using System;
using System.Collections.Generic;

namespace PayCRM.DAL
{
    public class ClientRepository
    {
        private IList<ClientModel> Clients;
        #region Public constructor
        public ClientRepository()
        {
            Clients = new List<ClientModel>();
            var client = new ClientModel() { Name = "Client #1", Address = "Street A", City = "City A" };
            client.ImportantDates.Add(new ImportantDateModel() { Date = DateTime.Now, Description = "Birthday", Alarm = false });
            client.ImportantDates.Add(new ImportantDateModel() { Date = DateTime.Now, Description = "Wedding anniversary", Alarm = true });
            client.ImportantDates.Add(new ImportantDateModel() { Date = DateTime.Now, Description = "1st born birthday", Alarm = false });
            Clients.Add(client);

            client = new ClientModel() { Name = "Client #2", Address = "Street B", City = "City B" };
            client.ImportantDates.Add(new ImportantDateModel() { Date = DateTime.Now, Description = "2nd born birthday", Alarm = false });
            Clients.Add(client);

        }
        #endregion

        #region Client CRUD methods
        public string Add(ClientModel obj)
        {
            Clients.Add(obj);
            return obj._id;
        }

        public IQueryable<ClientModel> GetAll()
        {
            return Clients.AsQueryable();
        }

        public ClientModel GetById(string Id)
        {
            return GetAll().Where(w => w._id == Id).SingleOrDefault();
        }

        public void Update(string Id, ClientModel obj)
        {
            var q = Clients.Where(w => w._id == Id).SingleOrDefault();
            if (q != null)
            {
                q.Address = obj.Address;
                q.City = obj.City;
                q.ImportantDates = obj.ImportantDates;
                q.Name = obj.Name;
            }            
        }

        public void Delete(string Id)
        {
            var q = Clients.Where(w => w._id == Id).SingleOrDefault();
            if (q != null)
            {
                Clients.Remove(q);
            }
        }        
        #endregion

        #region Alarm CRUD methods
        public void AddImportantDate(string ClientId, ImportantDateModel obj)
        {
            var client = GetById(ClientId);
            client.ImportantDates.Add(obj);
            Update(ClientId, client);
        }

        public void UpdateImportantDate(string ClientId, ImportantDateModel obj)
        {
            var client = GetById(ClientId);
            var date = client.ImportantDates.Where(w => w._id == obj._id).Single();
            date.Date = obj.Date;
            date.Description = obj.Description;
            date.Alarm = obj.Alarm;
            Update(ClientId, client);
        }

        public void DeleteImportantDate(string ClientId, string ImportantDateId)
        {
            var client = GetById(ClientId);
            var date = client.ImportantDates.Where(w => w._id == ImportantDateId).Single();
            client.ImportantDates.Remove(date);
            Update(ClientId, client);
        }
        #endregion        
    }
}
